==> haskell-tamarin-prover-sapic-1.10.0-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-sapic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tamarin-prover-sapic
version:              1.10.0
visibility:           public
id:                   tamarin-prover-sapic-1.10.0-6AqkeTX43f6CssXakBaQnv
key:                  tamarin-prover-sapic-1.10.0-6AqkeTX43f6CssXakBaQnv
license:              LicenseRef-GPL
copyright:
    Robert Künnemann, Alexander Dax, CISPA-Helmholtz-Centre Saarbrücken, 2019

maintainer:           Robert Künnemann <robert@kunnemann.de>
author:
    Robert Künnemann <robert@kunnemann.de>,
    Alexander Dax <alexander.dax@cispa.saarland>

homepage:             https://tamarin-prover.github.io/
synopsis:
    Library for input processes in SAPIC calculus for the tamarin prover.

description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).

    This library provides a translation from processes stated in the SAPIC calculus into multiset rewrite rules.

category:             Theorem Provers
abi:                  257dd0dbb97e6fad7e4aa460d5ca2276
exposed:              True
exposed-modules:
    Sapic Sapic.Annotation Sapic.Basetranslation Sapic.Bindings
    Sapic.Compression Sapic.Exceptions Sapic.Facts Sapic.LetDestructors
    Sapic.Locks Sapic.ProcessUtils Sapic.ProgressFunction
    Sapic.ProgressTranslation Sapic.ReliableChannelTranslation
    Sapic.Report Sapic.SecretChannels Sapic.States Sapic.Typing
    Sapic.Warnings

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tamarin-prover-sapic-1.10.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tamarin-prover-sapic-1.10.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tamarin-prover-sapic-1.10.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-sapic
hs-libraries:         HStamarin-prover-sapic-1.10.0-6AqkeTX43f6CssXakBaQnv
depends:
    aeson-2.1.2.1-H9spCVKCz3aBZuysSTfrjv
    aeson-pretty-0.8.10-5stj9KWMSZFHjUExBVCNKN base-4.17.2.1
    binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    dlist-1.0-I6FB5Nlk17hG16fxQzZSEb exceptions-0.10.5
    fclabels-2.0.5.1-F3LPv6eM58v2YqozGOd3NJ mtl-2.2.2
    parallel-3.2.2.0-KJ5o3ImR3G8wdLWLqGjpy parsec-3.1.16.1
    process-1.6.18.0 raw-strings-qq-1.1-73kb7SizjX3bDDbE8dc5y
    safe-0.3.21-D0Qa6qmXFrgLhocJR17U7j
    tamarin-prover-term-1.10.0-2kSd2Olki8A2iLJ6kAoYez
    tamarin-prover-theory-1.10.0-2Y6yTCTZwuTJXuTTkb963b
    tamarin-prover-utils-1.10.0-DmYJgvZuI7JJtsyuqDzkYR text-2.0.2
    transformers-0.5.6.2 uniplate-1.6.13-8GWqyDLzdG1GIR763aHdX

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-sapic/html/tamarin-prover-sapic.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-sapic/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tamarin-prover-sapic-1.10.0-67-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-sapic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tamarin-prover-sapic
version:              1.10.0
visibility:           public
id:                   tamarin-prover-sapic-1.10.0-BoEu5B8tZESEG61W2L8GOp
key:                  tamarin-prover-sapic-1.10.0-BoEu5B8tZESEG61W2L8GOp
license:              LicenseRef-GPL
copyright:
    Robert Künnemann, Alexander Dax, CISPA-Helmholtz-Centre Saarbrücken, 2019

maintainer:           Robert Künnemann <robert@kunnemann.de>
author:
    Robert Künnemann <robert@kunnemann.de>,
    Alexander Dax <alexander.dax@cispa.saarland>

homepage:             https://tamarin-prover.github.io/
synopsis:
    Library for input processes in SAPIC calculus for the tamarin prover.

description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).

    This library provides a translation from processes stated in the SAPIC calculus into multiset rewrite rules.

category:             Theorem Provers
abi:                  d99f77eebfc6969e56cb28c02a714179
exposed:              True
exposed-modules:
    Sapic Sapic.Annotation Sapic.Basetranslation Sapic.Bindings
    Sapic.Compression Sapic.Exceptions Sapic.Facts Sapic.LetDestructors
    Sapic.Locks Sapic.ProcessUtils Sapic.ProgressFunction
    Sapic.ProgressTranslation Sapic.ReliableChannelTranslation
    Sapic.Report Sapic.SecretChannels Sapic.States Sapic.Typing
    Sapic.Warnings

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tamarin-prover-sapic-1.10.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tamarin-prover-sapic-1.10.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tamarin-prover-sapic-1.10.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-sapic
hs-libraries:         HStamarin-prover-sapic-1.10.0-BoEu5B8tZESEG61W2L8GOp
depends:
    aeson-2.1.2.1-Gng3eoGBP2Sj2fbUBsnWH
    aeson-pretty-0.8.10-1UVA7jwF3AY2XeDKFp8bmR base-4.17.2.1
    binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    dlist-1.0-I6FB5Nlk17hG16fxQzZSEb exceptions-0.10.5
    fclabels-2.0.5.1-FOTYrQELIixAKTAvj4UJFl mtl-2.2.2
    parallel-3.2.2.0-KJ5o3ImR3G8wdLWLqGjpy parsec-3.1.16.1
    process-1.6.18.0 raw-strings-qq-1.1-73kb7SizjX3bDDbE8dc5y
    safe-0.3.21-GZFxfFIeXyQJFmn6rktbsO
    tamarin-prover-term-1.10.0-4tHv7QXAtZuCEJ9u2vJ5c7
    tamarin-prover-theory-1.10.0-CYiom5DtOWeFwG7k18y4bQ
    tamarin-prover-utils-1.10.0-KTMoxTNjrPcF12xo4PXPJF text-2.0.2
    transformers-0.5.6.2 uniplate-1.6.13-4BzKByujp41Ba8BKx5xnLI

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-sapic/html/tamarin-prover-sapic.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-sapic/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
